<?php

/**
 * @file
 * This file executes in early bootstrap to rewrite the client IP address.
 */

/**
 * Initialize IP address.
 */
function cryptolog_initialize() {
  // If no supported backends are found then return.
  foreach (array(
    'dmemcache_set' => 'dmemcache_get',
    'apcu_store' => 'apcu_fetch',
    'apc_store' => 'apc_fetch',
    'xcache_set' => 'xcache_get',
  ) as $set => $get) {
    if (function_exists($set)) {
      $cryptolog = $get('cryptolog');
      $day = gmdate('zY');
      if (!$cryptolog || $cryptolog['day'] !== $day) {
        $cryptolog = array('day' => $day, 'salt' => drupal_random_bytes(32));
        $set('cryptolog', $cryptolog, 86400);
      }
      // Generate a keyed hash in IPv6 address notation.
      $_SERVER['REMOTE_ADDR'] = inet_ntop(hash_hmac('md5', cryptolog_ip_address(), $cryptolog['salt'], TRUE));
      drupal_static_reset('ip_address');
      break;
    }
  }
}

/**
 * Returns original IP address.
 */
function cryptolog_ip_address() {
  static $ip_address;
  if (!$ip_address) {
    $ip_address = ip_address();
  }
  return $ip_address;
}

cryptolog_initialize();
